jdk/src/windows/classes/sun/security/mscapi/RSASignature.java
changeset 12685 8a448b5b9006
parent 11521 d7698e6c5f51
child 12700 9c9ad46c7c40
--- a/jdk/src/windows/classes/sun/security/mscapi/RSASignature.java	Tue May 08 11:16:36 2012 -0700
+++ b/jdk/src/windows/classes/sun/security/mscapi/RSASignature.java	Tue May 08 17:57:48 2012 -0700
@@ -47,6 +47,7 @@
  *
  *  . "NONEwithRSA"
  *  . "SHA1withRSA"
+ *  . "SHA224withRSA"
  *  . "SHA256withRSA"
  *  . "SHA384withRSA"
  *  . "SHA512withRSA"
@@ -57,8 +58,8 @@
  *
  * NOTE: NONEwithRSA must be supplied with a pre-computed message digest.
  *       Only the following digest algorithms are supported: MD5, SHA-1,
  *       SHA-256, SHA-384, SHA-512 and a special-purpose digest algorithm
  *       which is a concatenation of SHA-1 and MD5 digests.
  *
  * @since   1.6
  * @author  Stanley Man-Kit Ho
@@ -180,6 +181,8 @@
                 setDigestName("SHA-512");
             } else if (offset == 16) {
                 setDigestName("MD5");
+            } else if (offset == 28) {
+                setDigestName("SHA-224");
             } else {
                 throw new SignatureException(
                     "Message digest length is not supported");
@@ -199,6 +202,12 @@
         }
     }
 
+    public static final class SHA224 extends RSASignature {
+        public SHA224() {
+            super("SHA-224");
+        }
+    }
+
     public static final class SHA256 extends RSASignature {
         public SHA256() {
             super("SHA-256");
@@ -57,8 +58,8 @@
  * NOTE: NONEwithRSA must be supplied with a pre-computed message digest.
  *       Only the following digest algorithms are supported: MD5, SHA-1,
- *       SHA-256, SHA-384, SHA-512 and a special-purpose digest algorithm
- *       which is a concatenation of SHA-1 and MD5 digests.
+ *       SHA-224, SHA-256, SHA-384, SHA-512 and a special-purpose digest
+ *       algorithm which is a concatenation of SHA-1 and MD5 digests.
  *
  * @since   1.6